
# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


import os.path

readme = ''
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'README.rst'), 'rb') as stream:
    readme = stream.read().decode('utf8')


setup(
    long_description=readme,
    name='dephell-licenses',
    version='0.1.4',
    description='Get info about OSS licenses',
    python_requires='>=3.5',
    project_urls={'repository': 'https://github.com/dephell/dephell_licenses'},
    author='Gram',
    author_email='master_fess@mail.ru',
    license='MIT',
    keywords='dephell packaging licenses pypi',
    classifiers=['Development Status :: 4 - Beta', 'Intended Audience :: Developers', 'License :: OSI Approved :: MIT License', 'Programming Language :: Python', 'Topic :: Software Development :: Libraries :: Python Modules', 'Programming Language :: Python :: 3.5', 'Programming Language :: Python :: 3.6', 'Programming Language :: Python :: 3.7', 'Programming Language :: Python :: 3.8', 'Programming Language :: Python :: Implementation :: CPython', 'Programming Language :: Python :: Implementation :: PyPy', 'Operating System :: MacOS', 'Operating System :: Microsoft :: Windows', 'Operating System :: Unix'],
    packages=['dephell_licenses'],
    package_data={'dephell_licenses': ['*.json']},
    install_requires=['attrs', 'requests'],
)
